==> nextcloud-17.0.2.tar.bz2: nextcloud/apps/files/l10n/tr.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Depolama geçici olarak kullanılamıyor",
    "Storage invalid" : "Depolama geçersiz",
    "Unknown error" : "Bilinmeyen sorun",
    "All files" : "Tüm dosyalar",
    "Recent" : "Son",
    "Favorites" : "Sık Kullanılanlar",
    "File could not be found" : "Dosya bulunamadı",
    "Move or copy" : "Taşı ya da kopyala",
    "Download" : "İndir",
    "Delete" : "Sil",
    "Home" : "Giriş",
    "Close" : "Kapat",
    "Could not create folder \"{dir}\"" : "\"{dir}\" klasörü oluşturulamadı",
    "This will stop your current uploads." : "Bu işlem geçerli yüklemeleri durduracak.",
    "Upload cancelled." : "Yükleme iptal edildi.",
    "Processing files …" : "Dosyalar işleniyor …",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "{filename} bir klasör ya da 0 bayt boyutunda olduğundan yüklenemedi",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Yeterli boş alan yok. Yüklemek istediğiniz boyut {size1} ancak yalnız {size2} boş alan var",
    "Target folder \"{dir}\" does not exist any more" : "\"{dir}\" hedef klasörü artık yok",
    "Not enough free space" : "Yeterli boş alan yok",
    "An unknown error has occurred" : "Bilinmeyen bir sorun çıktı",
    "Uploading …" : "Yükleniyor …",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} / {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Bu ögenin yüklenmesi desteklenmiyor",
    "Target folder does not exist any more" : "Hedef klasör artık yok",
    "Error when assembling chunks, status code {status}" : "Kümeler oluşturulurken sorun çıktı, durum kodu {status}",
    "Actions" : "İşlemler",
    "Rename" : "Yeniden adlandır",
    "Copy" : "Kopyala",
    "Choose target folder" : "Hedef klasörü seçin",
    "Open" : "Aç",
    "Delete file" : "Dosyayı sil",
    "Delete folder" : "Klasörü sil",
    "Disconnect storage" : "Depolama bağlantısını kes",
    "Unshare" : "Paylaşımı kaldır",
    "Could not load info for file \"{file}\"" : "\"{file}\" dosyasının bilgileri alınamadı",
    "Files" : "Dosyalar",
    "Details" : "Ayrıntılar",
    "Select" : "Seçin",
    "Pending" : "Bekliyor",
    "Unable to determine date" : "Tarih belirlenemedi",
    "This operation is forbidden" : "Bu işleme izin verilmiyor",
    "This directory is unavailable, please check the logs or contact the administrator" : "Bu klasör yazılabilir değil. Lütfen günlük kayıtlarına bakın ya da yönetici ile görüşün",
    "Could not move \"{file}\", target exists" : "\"{file}\" taşınamadı, hedef zaten var",
    "Could not move \"{file}\"" : "\"{file}\" taşınamadı",
    "copy" : "kopya",
    "Could not copy \"{file}\", target exists" : "\"{file}\" dosyası kopyalanamadı, hedef zaten var",
    "Could not copy \"{file}\"" : "\"{file}\" kopyalanamadı",
    "Copied {origin} inside {destination}" : "{origin} dosyası, {destination} içine kopyalandı",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} ve diğer {nbfiles} dosya, {destination} içine kopyalandı",
    "{newName} already exists" : "{newName} zaten var",
    "Could not rename \"{fileName}\", it does not exist any more" : "\"{fileName}\" yeniden adlandırılamadı, artık yok",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{targetName}\" adı \"{dir}\" klasöründe zaten var. Lütfen farklı bir ad seçin.",
    "Could not rename \"{fileName}\"" : "\"{fileName}\" yeniden adlandırılamadı",
    "Could not create file \"{file}\"" : "\"{file}\" dosyası oluşturulamadı",
    "Could not create file \"{file}\" because it already exists" : "\"{file}\" dosyası zaten var olduğundan oluşturulamadı",
    "Could not create folder \"{dir}\" because it already exists" : "\"{dir}\" klasörü zaten var olduğundan oluşturulamadı",
    "Error deleting file \"{fileName}\"." : "\"{fileName}\" dosyası silinirken sorun çıktı.",
    "No search results in other folders for {tag}{filter}{endtag}" : "{tag}{filter}{endtag} için diğer klasörlerde herhangi bir arama sonucu yok",
    "Name" : "Ad",
    "Size" : "Boyut",
    "Modified" : "Değiştirilme",
    "_%n folder_::_%n folders_" : ["%n klasör","%n klasör"],
    "_%n file_::_%n files_" : ["%n dosya","%n dosya"],
    "{dirs} and {files}" : "{dirs} ve {files}",
    "_including %n hidden_::_including %n hidden_" : ["%n gizli ile birlikte","%n gizli ile birlikte"],
    "You don’t have permission to upload or create files here" : "Buraya dosya yükleme ya da ekleme izniniz yok",
    "_Uploading %n file_::_Uploading %n files_" : ["%n dosya yükleniyor","%n dosya yükleniyor"],
    "New" : "Yeni",
    "Select file range" : "Dosya aralığını seçin",
    "{used} of {quota} used" : "{used} / {quota} kullanılmış",
    "{used} used" : "{used} kullanılmış",
    "\"{name}\" is an invalid file name." : "\"{name}\" geçersiz bir dosya adı.",
    "File name cannot be empty." : "Dosya adı boş olamaz.",
    "\"/\" is not allowed inside a file name." : "Dosya adında \"/\" kullanılamaz.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" dosya türüne izin verilmiyor",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} için boş depolama alanı kalmadı. Artık dosyalar güncellenmeyecek ya da eşitlenmeyecek!",
    "Your storage is full, files can not be updated or synced anymore!" : "Boş depolama alanınız kalmadı. Artık dosyalar güncellenmeyecek ya da eşitlenmeyecek!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} boş depolama alanı bitmek üzere ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Boş depolama alanınız bitmek üzere (%{usedSpacePercent})",
    "_matches '{filter}'_::_match '{filter}'_" : ["'{filter}' ile eşleşen","'{filter}' ile eşleşen"],
    "View in folder" : "Klasörde görüntüle",
    "Copied!" : "Kopyalandı!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Doğrudan bağlantıyı kopyala (yalnız bu dosya ya da klasöre erişim izni olan kullanıcılar için)",
    "Path" : "Yol",
    "_%n byte_::_%n bytes_" : ["%n bayt","%n bayt"],
    "Favorited" : "Sık kullanılanlara eklendi",
    "Favorite" : "Sık kullanılanlara ekle",
    "You can only favorite a single file or folder at a time" : "Aynı anda yalnız bir dosya ya da bir klasör sık kullanılanlara eklenebilir",
    "New folder" : "Yeni klasör",
    "Upload file" : "Dosya yükle",
    "Not favorited" : "Sık kullanılanlarda değil",
    "Remove from favorites" : "Sık kullanılanlardan kaldır",
    "Add to favorites" : "Sık kullanılanlara ekle",
    "An error occurred while trying to update the tags" : "Etiketler güncellenirken bir sorun çıktı",
    "Added to favorites" : "Sık kullanılanlara eklendi",
    "Removed from favorites" : "Sık kullanılanlardan çıkarıldı",
    "You added {file} to your favorites" : "{file} dosyasını sık kullandıklarınıza eklediniz",
    "You removed {file} from your favorites" : "{file} dosyasını sık kullandıklarınızdan çıkardınız",
    "File changes" : "Dosya değişikleri",
    "Created by {user}" : "{user} tarafından eklendi",
    "Changed by {user}" : "{user} tarafından değiştirildi",
    "Deleted by {user}" : "{user} tarafından silindi",
    "Restored by {user}" : "{user} tarafından geri yüklendi",
    "Renamed by {user}" : "{user} tarafından adı değiştirildi",
    "Moved by {user}" : "{user} tarafından taşındı",
    "\"remote user\"" : "\"uzak kullanıcı\"",
    "You created {file}" : "{file} dosyasını eklediniz",
    "You created an encrypted file in {file}" : "{file} içinde şifrelenmiş bir dosya oluşturdunuz",
    "{user} created {file}" : "{user}, {file} dosyasını ekledi",
    "{user} created an encrypted file in {file}" : "{user} kullanıcısı {file} içinde şifrelenmiş bir dosya oluşturdu",
    "{file} was created in a public folder" : "{file} dosyası herkese açık klasör içine eklendi",
    "You changed {file}" : "{file} dosyasını değiştirdiniz",
    "You changed an encrypted file in {file}" : "{file} içindeki şifrelenmiş bir dosyayı değiştirdiniz",
    "{user} changed {file}" : "{user}, {file} dosyasını değiştirdi",
    "{user} changed an encrypted file in {file}" : "{user} kullanıcısı {file} içindeki şifrelenmiş bir dosyayı değiştirdi",
    "You deleted {file}" : "{file} dosyasını sildiniz",
    "You deleted an encrypted file in {file}" : "{file} içindeki şifrelenmiş bir dosyayı sildiniz",
    "{user} deleted {file}" : "{user}, {file} dosyasını sildi",
    "{user} deleted an encrypted file in {file}" : "{user} kullanıcısı {file} içindeki şifrelenmiş bir dosyayı sildi",
    "You restored {file}" : "{file} dosyasını geri yüklediniz",
    "{user} restored {file}" : "{user}, {file} dosyasını geri yükledi",
    "You renamed {oldfile} to {newfile}" : "{oldfile} dosyasının adını {newfile} olarak değiştirdiniz",
    "{user} renamed {oldfile} to {newfile}" : "{user}, {oldfile} dosyasının adını {newfile} olarak değiştirdi",
    "You moved {oldfile} to {newfile}" : "{oldfile} dosyasını {newfile} klasörüne taşıdınız",
    "{user} moved {oldfile} to {newfile}" : "{user}, {oldfile} dosyasının {newfile} dosyasına taşıdı",
    "A file has been added to or removed from your <strong>favorites</strong>" : "<strong>Sık kullandıklarınıza</strong> bir dosya eklendi ya da silindi",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Bir dosya ya da klasör <strong>değiştirildi</strong> ya da <strong>yeniden adlandırıldı</strong>",
    "A new file or folder has been <strong>created</strong>" : "Yeni bir dosya ya da klasör <strong>eklendi</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Bir dosya ya da klasör <strong>silindi</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "<strong>Sık kullanılan dosyalarınız</strong> ile ilgili ekleme ve değişiklik bildirimleri sınırlansın <em>(Yalnız akış)</em>",
    "A file or folder has been <strong>restored</strong>" : "Bir dosya ya da klasör <strong>geri yüklendi</strong>",
    "Unlimited" : "Sınırsız",
    "Upload (max. %s)" : "Yükle (en büyük: %s)",
    "Accept" : "Kabul Et",
    "File Management" : "Dosya Yönetimi",
    "Invalid path selected" : "Seçilen yol geçersiz",
    "Ownership transfer request sent" : "Sahiplik aktarımı isteği gönderildi",
    "Error while loading the file data" : "Dosya verileri yüklenirken sorun çıktı",
    "Unable to change the favourite state of the file" : "Dosyanın sık kullanılan durumu değiştirilemedi",
    "%s used" : "%s kullanılıyor",
    "%s%% of %s used" : "%s%%/%s kullanılmış",
    "%1$s of %2$s used" : "%1$s / %2$s kullanıldı",
    "Settings" : "Ayarlar",
    "Show hidden files" : "Gizli dosyaları görüntüle",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Dosyalarınıza WebDAV üzerinden erişmek için <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">bu adresi kullanın</a>",
    "Toggle grid view" : "Tablo görünümünü değiştir",
    "No files in here" : "Burada herhangi bir dosya yok",
    "Upload some content or sync with your devices!" : "Bir şeyler yükleyin ya da aygıtlarınızla eşitleyin!",
    "No entries found in this folder" : "Bu klasörde herhangi bir kayıt bulunamadı",
    "Select all" : "Tümünü seç",
    "Upload too large" : "Yükleme boyutu çok büyük",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Yüklemeye çalıştığınız dosyalar bu sunucuya yüklenmesine izin verilen en büyük dosya boyutunu aşıyor.",
    "No favorites yet" : "Henüz sık kullanılan bir öge yok",
    "Files and folders you mark as favorite will show up here" : "Sık kullanılanlara eklediğiniz dosya ve klasörler burada görüntülenir",
    "Tags" : "Etiketler",
    "Deleted files" : "Silinmiş dosyalar",
    "Shares" : "Paylaşımlar",
    "Shared with others" : "Diğerleri ile paylaşılan",
    "Shared with you" : "Sizinle paylaşılan",
    "Shared by link" : "Bağlantı ile paylaşılmış",
    "Deleted shares" : "Silinmiş paylaşımlar",
    "Text file" : "Metin dosyası",
    "New text file.txt" : "Yeni metin dosyası.txt",
    "File handling" : "Dosya işlemleri",
    "Maximum upload size" : "En büyük yükleme boyutu",
    "max. possible: " : "olabilecek en büyük:",
    "Save" : "Kaydet",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "PHP-FPM üzerinde değişikliklerin uygulanması 5 dakika sürebilir.",
    "Missing permissions to edit from here." : "Buradan düzenleme için izinler eksik.",
    "Cancel upload" : "Yüklemeyi iptal et",
    "%s of %s used" : "%s / %s kullanılıyor",
    "%1$s%% of %2$s used" : "%1$s%% / %2$s kullanılmış"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-21.0.0.tar.bz2: nextcloud/apps/files/l10n/tr.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Depolama geçici olarak kullanılamıyor",
    "Storage invalid" : "Depolama geçersiz",
    "Unknown error" : "Bilinmeyen sorun",
    "File could not be found" : "Dosya bulunamadı",
    "Move or copy" : "Taşı ya da kopyala",
    "Download" : "İndir",
    "Delete" : "Sil",
    "Home" : "Giriş",
    "Close" : "Kapat",
    "Favorites" : "Sık Kullanılanlar",
    "Could not create folder \"{dir}\"" : "\"{dir}\" klasörü oluşturulamadı",
    "This will stop your current uploads." : "Bu işlem geçerli yüklemeleri durduracak.",
    "Upload cancelled." : "Yükleme iptal edildi.",
    "Processing files …" : "Dosyalar işleniyor …",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "{filename} bir klasör ya da 0 bayt boyutunda olduğundan yüklenemedi",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Yeterli boş alan yok. Yüklemek istediğiniz boyut {size1} ancak yalnız {size2} boş alan var",
    "Target folder \"{dir}\" does not exist any more" : "\"{dir}\" hedef klasörü artık yok",
    "Not enough free space" : "Yeterli boş alan yok",
    "An unknown error has occurred" : "Bilinmeyen bir sorun çıktı",
    "Uploading …" : "Yükleniyor …",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} / {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Bu ögenin yüklenmesi desteklenmiyor",
    "Target folder does not exist any more" : "Hedef klasör artık yok",
    "Operation is blocked by access control" : "İşlem erişim denetimi tarafından engellendi",
    "Error when assembling chunks, status code {status}" : "Kümeler oluşturulurken sorun çıktı, durum kodu {status}",
    "Actions" : "İşlemler",
    "Rename" : "Yeniden adlandır",
    "Copy" : "Kopyala",
    "Choose target folder" : "Hedef klasörü seçin",
    "Open" : "Aç",
    "Delete file" : "Dosyayı sil",
    "Delete folder" : "Klasörü sil",
    "Disconnect storage" : "Depolama bağlantısını kes",
    "Leave this share" : "Bu paylaşımdan ayrıl",
    "Could not load info for file \"{file}\"" : "\"{file}\" dosyasının bilgileri alınamadı",
    "Files" : "Dosyalar",
    "Details" : "Ayrıntılar",
    "Select" : "Seçin",
    "Pending" : "Bekliyor",
    "Unable to determine date" : "Tarih belirlenemedi",
    "This operation is forbidden" : "Bu işleme izin verilmiyor",
    "This directory is unavailable, please check the logs or contact the administrator" : "Bu klasör yazılabilir değil. Lütfen günlük kayıtlarına bakın ya da BT yöneticiniz ile görüşün",
    "Could not move \"{file}\", target exists" : "\"{file}\" taşınamadı, hedef zaten var",
    "Could not move \"{file}\"" : "\"{file}\" taşınamadı",
    "copy" : "kopya",
    "Could not copy \"{file}\", target exists" : "\"{file}\" dosyası kopyalanamadı, hedef zaten var",
    "Could not copy \"{file}\"" : "\"{file}\" kopyalanamadı",
    "Copied {origin} inside {destination}" : "{origin} dosyası, {destination} içine kopyalandı",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} ve diğer {nbfiles} dosya, {destination} içine kopyalandı",
    "{newName} already exists" : "{newName} zaten var",
    "Could not rename \"{fileName}\", it does not exist any more" : "\"{fileName}\" yeniden adlandırılamadı, artık yok",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{targetName}\" adı \"{dir}\" klasöründe zaten var. Lütfen farklı bir ad seçin.",
    "Could not rename \"{fileName}\"" : "\"{fileName}\" yeniden adlandırılamadı",
    "Could not create file \"{file}\"" : "\"{file}\" dosyası oluşturulamadı",
    "Could not create file \"{file}\" because it already exists" : "\"{file}\" dosyası zaten var olduğundan oluşturulamadı",
    "Could not create folder \"{dir}\" because it already exists" : "\"{dir}\" klasörü zaten var olduğundan oluşturulamadı",
    "Could not fetch file details \"{file}\"" : "\"{file}\" dosyasının ayrıntıları alınamadı",
    "Error deleting file \"{fileName}\"." : "\"{fileName}\" dosyası silinirken sorun çıktı.",
    "No search results in other folders for {tag}{filter}{endtag}" : "{tag}{filter}{endtag} için diğer klasörlerde herhangi bir arama sonucu yok",
    "Enter more than two characters to search in other folders" : "Diğer klasörlerde aramak için iki karakterden fazla yazın",
    "Name" : "Ad",
    "Size" : "Boyut",
    "Modified" : "Değiştirilme",
    "_%n folder_::_%n folders_" : ["%n klasör","%n klasör"],
    "_%n file_::_%n files_" : ["%n dosya","%n dosya"],
    "{dirs} and {files}" : "{dirs} ve {files}",
    "_including %n hidden_::_including %n hidden_" : ["%n gizli ile birlikte","%n gizli ile birlikte"],
    "You don’t have permission to upload or create files here" : "Buraya dosya yükleme ya da ekleme izniniz yok",
    "_Uploading %n file_::_Uploading %n files_" : ["%n dosya yükleniyor","%n dosya yükleniyor"],
    "New" : "Yeni",
    "Select file range" : "Dosya aralığını seçin",
    "{used} of {quota} used" : "{used} / {quota} kullanılmış",
    "{used} used" : "{used} kullanılmış",
    "\"{name}\" is an invalid file name." : "\"{name}\" geçersiz bir dosya adı.",
    "File name cannot be empty." : "Dosya adı boş olamaz.",
    "\"/\" is not allowed inside a file name." : "Dosya adında \"/\" kullanılamaz.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" dosya türüne izin verilmiyor",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} için boş depolama alanı kalmadı. Artık dosyalar güncellenmeyecek ya da eşitlenmeyecek!",
    "Group folder \"{mountPoint}\" is full, files can not be updated or synced anymore!" : "\"{mountPoint}\" grup klasöründe boş alan kalmadı. Artık güncellenemeyecek ya da eşitlenemeyecek!",
    "External storage \"{mountPoint}\" is full, files can not be updated or synced anymore!" : "\"{mountPoint}\" dış depolamasında boş alan kalmadı. Artık güncellenemeyecek ya da eşitlenemeyecek!",
    "Your storage is full, files can not be updated or synced anymore!" : "Boş depolama alanınız kalmadı. Artık dosyalar güncellenmeyecek ya da eşitlenmeyecek!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "{owner} boş depolama alanı bitmek üzere ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "\"{mountPoint}\" grup klasöründeki boş alan bitmek üzere ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "\"{mountPoint}\" dış depolamasındaki boş alan bitmek üzere ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Boş depolama alanınız bitmek üzere ({usedSpacePercent}%).",
    "_matches '{filter}'_::_match '{filter}'_" : ["'{filter}' ile eşleşen","'{filter}' ile eşleşen"],
    "View in folder" : "Klasörde görüntüle",
    "Copied!" : "Kopyalandı!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Doğrudan bağlantıyı kopyala (yalnız bu dosya ya da klasöre erişim izni olan kullanıcılar için)",
    "Path" : "Yol",
    "_%n byte_::_%n bytes_" : ["%n bayt","%n bayt"],
    "Favorited" : "Sık kullanılanlara eklendi",
    "Favorite" : "Sık kullanılanlara ekle",
    "You can only favorite a single file or folder at a time" : "Aynı anda yalnız bir dosya ya da bir klasör sık kullanılanlara eklenebilir",
    "New folder" : "Yeni klasör",
    "Upload file" : "Dosya yükle",
    "Recent" : "Son",
    "Not favorited" : "Sık kullanılanlarda değil",
    "Remove from favorites" : "Sık kullanılanlardan kaldır",
    "Add to favorites" : "Sık kullanılanlara ekle",
    "An error occurred while trying to update the tags" : "Etiketler güncellenirken bir sorun çıktı",
    "Added to favorites" : "Sık kullanılanlara eklendi",
    "Removed from favorites" : "Sık kullanılanlardan çıkarıldı",
    "You added {file} to your favorites" : "{file} dosyasını sık kullandıklarınıza eklediniz",
    "You removed {file} from your favorites" : "{file} dosyasını sık kullandıklarınızdan çıkardınız",
    "File changes" : "Dosya değişikleri",
    "Created by {user}" : "{user} tarafından eklendi",
    "Changed by {user}" : "{user} tarafından değiştirildi",
    "Deleted by {user}" : "{user} tarafından silindi",
    "Restored by {user}" : "{user} tarafından geri yüklendi",
    "Renamed by {user}" : "{user} tarafından adı değiştirildi",
    "Moved by {user}" : "{user} tarafından taşındı",
    "\"remote user\"" : "\"uzak kullanıcı\"",
    "You created {file}" : "{file} dosyasını eklediniz",
    "You created an encrypted file in {file}" : "{file} içinde şifrelenmiş bir dosya oluşturdunuz",
    "{user} created {file}" : "{user}, {file} dosyasını ekledi",
    "{user} created an encrypted file in {file}" : "{user} kullanıcısı {file} içinde şifrelenmiş bir dosya oluşturdu",
    "{file} was created in a public folder" : "{file} dosyası herkese açık klasör içine eklendi",
    "You changed {file}" : "{file} dosyasını değiştirdiniz",
    "You changed an encrypted file in {file}" : "{file} içindeki şifrelenmiş bir dosyayı değiştirdiniz",
    "{user} changed {file}" : "{user}, {file} dosyasını değiştirdi",
    "{user} changed an encrypted file in {file}" : "{user} kullanıcısı {file} içindeki şifrelenmiş bir dosyayı değiştirdi",
    "You deleted {file}" : "{file} dosyasını sildiniz",
    "You deleted an encrypted file in {file}" : "{file} içindeki şifrelenmiş bir dosyayı sildiniz",
    "{user} deleted {file}" : "{user}, {file} dosyasını sildi",
    "{user} deleted an encrypted file in {file}" : "{user} kullanıcısı {file} içindeki şifrelenmiş bir dosyayı sildi",
    "You restored {file}" : "{file} dosyasını geri yüklediniz",
    "{user} restored {file}" : "{user}, {file} dosyasını geri yükledi",
    "You renamed {oldfile} to {newfile}" : "{oldfile} dosyasının adını {newfile} olarak değiştirdiniz",
    "{user} renamed {oldfile} to {newfile}" : "{user}, {oldfile} dosyasının adını {newfile} olarak değiştirdi",
    "You moved {oldfile} to {newfile}" : "{oldfile} dosyasını {newfile} klasörüne taşıdınız",
    "{user} moved {oldfile} to {newfile}" : "{user}, {oldfile} dosyasının {newfile} dosyasına taşıdı",
    "A file has been added to or removed from your <strong>favorites</strong>" : "<strong>Sık kullandıklarınıza</strong> bir dosya eklendi ya da silindi",
    "A file or folder has been <strong>changed</strong>" : "Bir dosya ya da klasör <strong>değiştirildi</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Sık kullanılan bir dosya ya da klasör <strong>değiştirildi</strong>",
    "All files" : "Tüm dosyalar",
    "Unlimited" : "Sınırsız",
    "Upload (max. %s)" : "Yükle (en büyük: %s)",
    "Accept" : "Kabul Et",
    "Reject" : "Reddet",
    "Incoming ownership transfer from {user}" : "{user} kullanıcısından gelen sahiplik aktarımı ",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "{path} yolunu onaylamak istiyor musunuz?\n\nNot: Onay verdikten sonra aktarım işleminin tamamlanması 1 saat kadar sürebilir.",
    "Ownership transfer failed" : "Sahiplik aktarılamadı",
    "Your ownership transfer of {path} to {user} failed." : "{path} yolundaki sahipliğiniz {user} kullanıcısına aktarılamadı.",
    "The ownership transfer of {path} from {user} failed." : "{path} yolundaki {user} kullanıcısının sahipliği size aktarılamadı.",
    "Ownership transfer done" : "Sahiplik aktarıldı",
    "Your ownership transfer of {path} to {user} has completed." : "{path} yolundaki sahipliğiniz {user} kullanıcısına aktarıldı.",
    "The ownership transfer of {path} from {user} has completed." : "{path} yolundaki {user} kullanıcısının sahipliği size aktarıldı.",
    "in %s" : "%s içinde",
    "File Management" : "Dosya Yönetimi",
    "Transfer ownership of a file or folder" : "Bir dosya ya da klasörün sahipliğini aktar",
    "Choose file or folder to transfer" : "Sahipliği aktarılacak dosya ya da klasörü seçin",
    "Change" : "Değiştir",
    "New owner" : "Yeni sahip",
    "Search users" : "Kullanıcı arama",
    "Choose a file or folder to transfer" : "Sahipliği aktarılacak bir dosya ya da klasör seçin",
    "Transfer" : "Sahipliği Aktar",
    "Transfer {path} to {userid}" : "{path} yolunun sahipliğini {userid} kullanıcısına aktar",
    "Invalid path selected" : "Seçilen yol geçersiz",
    "Ownership transfer request sent" : "Sahiplik aktarımı isteği gönderildi",
    "Cannot transfer ownership of a file or folder you don't own" : "Sahibi olmadığınız bir dosya ya da klasörün sahipliğini aktaramazsınız",
    "Tags" : "Etiketler",
    "Unable to change the favourite state of the file" : "Dosyanın sık kullanılan durumu değiştirilemedi",
    "Error while loading the file data" : "Dosya verileri yüklenirken sorun çıktı",
    "Pick a template for {name}" : "{name} için bir kalıp seçin",
    "Cancel" : "İptal",
    "Create" : "Ekle",
    "Create a new file with the selected template" : "Seçilmiş kalıp ile yeni bir dosya ekle",
    "Creating file" : "Dosya ekleniyor",
    "Blank" : "Boş",
    "Unable to create new file from template" : "Kalıptan yeni dosya eklenemedi",
    "Set up templates folder" : "Kalıp klasörünü ayarlayın",
    "Templates" : "Kalıplar",
    "Unable to initialize the templates directory" : "Kalıp klasörü hazırlanamadı",
    "%s used" : "%s kullanılıyor",
    "%s%% of %s used" : "%s%%/%s kullanılmış",
    "%1$s of %2$s used" : "%1$s / %2$s kullanıldı",
    "Settings" : "Ayarlar",
    "Show hidden files" : "Gizli dosyaları görüntüle",
    "Crop image previews" : "Görsel ön izlemeleri kırpılsın",
    "WebDAV" : "WebDAV",
    "Use this address to access your Files via WebDAV" : "Dosyalarınıza WebDAV üzerinden erişmek için bu adresi kullanın",
    "Toggle grid view" : "Tablo görünümünü değiştir",
    "No files in here" : "Burada herhangi bir dosya yok",
    "Upload some content or sync with your devices!" : "Bir şeyler yükleyin ya da aygıtlarınızla eşitleyin!",
    "No entries found in this folder" : "Bu klasörde herhangi bir kayıt bulunamadı",
    "Select all" : "Tümünü seç",
    "Upload too large" : "Yükleme boyutu çok büyük",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Yüklemeye çalıştığınız dosyalar bu sunucuya yüklenmesine izin verilen en büyük dosya boyutunu aşıyor.",
    "No favorites yet" : "Henüz sık kullanılan bir öge yok",
    "Files and folders you mark as favorite will show up here" : "Sık kullanılanlara eklediğiniz dosya ve klasörler burada görüntülenir",
    "Deleted files" : "Silinmiş dosyalar",
    "Shares" : "Paylaşımlar",
    "Shared with others" : "Diğerleri ile paylaşılan",
    "Shared with you" : "Sizinle paylaşılan",
    "Shared by link" : "Bağlantı ile paylaşılmış",
    "Deleted shares" : "Silinmiş paylaşımlar",
    "Pending shares" : "Bekleyen paylaşımlar",
    "Text file" : "Metin dosyası",
    "New text file.txt" : "Yeni metin dosyası.txt",
    "Unshare" : "Paylaşımı kaldır",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} boş depolama alanı bitmek üzere ({usedSpacePercent}%)",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)" : "\"{mountPoint}\" grup klasöründeki boş alan bitmek üzere (%{usedSpacePercent}).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)" : "\"{mountPoint}\" dış depolamasındaki boş alan bitmek üzere (%{usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)" : "Boş depolama alanınız bitmek üzere (%{usedSpacePercent})",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Bir dosya ya da klasör <strong>değiştirildi</strong> ya da <strong>yeniden adlandırıldı</strong>",
    "A new file or folder has been <strong>created</strong>" : "Yeni bir dosya ya da klasör <strong>eklendi</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Bir dosya ya da klasör <strong>silindi</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "<strong>Sık kullanılan dosyalarınız</strong> ile ilgili ekleme ve değişiklik bildirimleri sınırlansın <em>(Yalnız akış)</em>",
    "A file or folder has been <strong>restored</strong>" : "Bir dosya ya da klasör <strong>geri yüklendi</strong>"
},
"nplurals=2; plural=(n > 1);");
